'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The Alert component
 * @param  {String}              style       The style of the alert
 * @param  {Boolean}             dismissible If true, then the alert is
 *                                           dismissible & will include a
 *                                           button which will remove the
 *                                           component when clicked
 * @param  {Array|React.Element} children    The child (or children) to display in this component
 * @return {React.Element}                   The React Element representing this component
 */
// dependencies
//
var Alert = function Alert(_ref) {
    var style = _ref.style;
    var dismissible = _ref.dismissible;
    var children = _ref.children;

    // determine the classes for the outermost div
    //
    var classes = (0, _classnames2.default)('alert', {
        'alert-danger': style === 'danger' || style === 'error',
        'alert-warning': style === 'warning' || style === 'warn',
        'alert-info': style === 'info',
        'alert-success': style === 'success' || style === 'ok' || !style,
        'alert-dismissible': dismissible
    });

    // return the React Element
    //
    return _react2.default.createElement(
        'div',
        { className: classes },
        dismissible && _react2.default.createElement(
            'button',
            {
                type: 'button',
                className: 'close',
                'data-dismiss': 'alert',
                'aria-label': 'Close'
            },
            _react2.default.createElement(
                'span',
                { 'aria-hidden': 'true' },
                '×'
            )
        ),
        children
    );
};

// set the property types for the Alert component
//
Alert.propTypes = {
    style: _react2.default.PropTypes.string,
    dismissible: _react2.default.PropTypes.bool,
    children: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.element, _react2.default.PropTypes.arrayOf(_react2.default.PropTypes.element)])
};

// export the component
//
exports.default = Alert;