'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactAddonsUpdate = require('react-addons-update');

var _reactAddonsUpdate2 = _interopRequireDefault(_reactAddonsUpdate);

var _uniqueId = require('lodash/uniqueId');

var _uniqueId2 = _interopRequireDefault(_uniqueId);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Alert = require('./Alert');

var _Alert2 = _interopRequireDefault(_Alert);

var _Button = require('./form/Button');

var _Button2 = _interopRequireDefault(_Button);

var _CheckboxGroup = require('./form/CheckboxGroup');

var _CheckboxGroup2 = _interopRequireDefault(_CheckboxGroup);

var _Dropdown = require('./form/Dropdown');

var _Dropdown2 = _interopRequireDefault(_Dropdown);

var _RadioButtonGroup = require('./form/RadioButtonGroup');

var _RadioButtonGroup2 = _interopRequireDefault(_RadioButtonGroup);

var _SubmitButton = require('./form/SubmitButton');

var _SubmitButton2 = _interopRequireDefault(_SubmitButton);

var _TextInput = require('./form/TextInput');

var _TextInput2 = _interopRequireDefault(_TextInput);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; } // dependencies
//


// @TODO add configurable columns
// @TODO changing values of children via props should trigger re-validation

/**
 * The Form component
 */
var Form = function (_React$Component) {
    _inherits(Form, _React$Component);

    /**
     * Construct the Form component instance
     * @param  {Object} props The component properties
     */
    function Form(props) {
        _classCallCheck(this, Form);

        // initialize the state, which consists of the validation messages for
        // any children. This is just an empty object now, but as child
        // components are mounted, they will "call in" via the
        // `onChildValidationEvent` handler, at which time this state will
        // become populated with values
        //
        var _this = _possibleConstructorReturn(this, (Form.__proto__ || Object.getPrototypeOf(Form)).call(this, props));

        _this.state = {
            validation: {},
            hasValidated: {}
        };

        // bind `this` to the `isValid` method
        //
        _this.isValid = _this.isValid.bind(_this);

        // bind `this` to the onChildValidationEvent handler
        //
        _this.onChildValidationEvent = _this.onChildValidationEvent.bind(_this);
        return _this;
    }

    /**
     * Get the child context values
     *
     * These  values are availabe for use by children of the Form component.
     *
     * @return {Object} The child context values
     */


    _createClass(Form, [{
        key: 'getChildContext',
        value: function getChildContext() {
            return {
                isValid: this.isValid(),
                labelColumns: this.props.labelColumns,
                onChildValidationEvent: this.onChildValidationEvent
            };
        }

        /**
         * Handle a validation event from one of the children of this Form
         * @param  {String} validationKey     A unique key identifying the child
         *                                    component
         * @param  {[type]} childHasValidated A flag to indicate whether the
         *                                    component has validated in response to
         *                                    user input
         * @param  {String|null} message      The validation error message, or null
         *                                    if the component is valid
         */

    }, {
        key: 'onChildValidationEvent',
        value: function onChildValidationEvent(validationKey, childHasValidated, message) {
            // build a change event to update the `validation` and `hasValidated`
            // state
            //
            var validation = {};
            validation[validationKey] = { $set: message };

            var hasValidated = {};
            hasValidated[validationKey] = { $set: !!childHasValidated };

            var delta = { validation: validation, hasValidated: hasValidated };

            // update the Form component state
            //
            this.setState(function (state) {
                return (0, _reactAddonsUpdate2.default)(state, delta);
            });
        }

        /**
         * Determine if the form is valid
         * @return {Boolean} If true, then all form components are valid
         */

    }, {
        key: 'isValid',
        value: function isValid() {
            // get the list of keys from the validation state
            //
            var keys = Object.keys(this.state.validation);

            // iterate over the list of keys
            //
            for (var idx = 0; idx < keys.length; idx++) {
                // do we have a validation error message for the current item? if
                // so, return false, since we have at least one component which has
                // failed validation
                //
                if (this.state.validation[keys[idx]]) {
                    return false;
                }
            }

            // if we get here, then none of the children have failed validation.
            // Return true
            //
            return true;
        }

        /**
         * Build a list of validation errors for the Form
         * @return {Array} An array of validation errors (possibly empty, if all
         *                 components are valid)
         */

    }, {
        key: 'validationErrors',
        value: function validationErrors() {
            var _this2 = this;

            // declare an array to hold the error messages
            //
            var errors = [];

            // iterate through the keys of the validation state and add non-null
            // messages for children which have validated to the array
            //
            Object.keys(this.state.validation).forEach(function (key) {
                if (_this2.state.hasValidated[key] && _this2.state.validation[key]) {
                    errors.push(_this2.state.validation[key]);
                }
            });

            // return the list of error messages
            //
            return errors;
        }

        /**
         * Render the component
         * @return {React.Element} The React element describing the component
         */

    }, {
        key: 'render',
        value: function render() {
            // get the list of validation error messages for the form
            //
            var errors = this.validationErrors();

            // if we have errors, then add an Alert component describing the
            // problems
            //
            var alert = errors.length > 0 ? _react2.default.createElement(
                _Alert2.default,
                { style: 'error' },
                _react2.default.createElement(
                    'p',
                    null,
                    'Please correct the following problems:'
                ),
                _react2.default.createElement(
                    'ul',
                    null,
                    errors.map(function (err) {
                        return _react2.default.createElement(
                            'li',
                            { key: (0, _uniqueId2.default)() },
                            err
                        );
                    })
                )
            ) : '';

            // render the component and return it
            //
            return _react2.default.createElement(
                'div',
                {
                    className: (0, _classnames2.default)({
                        'form-inline': this.props.inline,
                        'form-horizontal': this.props.horizontal
                    })
                },
                alert,
                this.props.children
            );
        }
    }]);

    return Form;
}(_react2.default.Component);

// set the property types for the component
//


Form.propTypes = {
    inline: _react2.default.PropTypes.bool,
    horizontal: _react2.default.PropTypes.bool,
    labelColumns: _react2.default.PropTypes.number,
    children: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.arrayOf(_react2.default.PropTypes.node), _react2.default.PropTypes.node]).isRequired
};

// set the child context types to propagate to the children
//
Form.childContextTypes = {
    isValid: _react2.default.PropTypes.bool,
    onChildValidationEvent: _react2.default.PropTypes.func,
    labelColumns: _react2.default.PropTypes.number
};

// register the "sub-components" so that they can be imported as part of the
// same package
//
Form.Button = _Button2.default;
Form.CheckboxGroup = _CheckboxGroup2.default;
Form.Dropdown = _Dropdown2.default;
Form.RadioButtonGroup = _RadioButtonGroup2.default;
Form.SubmitButton = _SubmitButton2.default;
Form.TextInput = _TextInput2.default;

// export the component
//
exports.default = Form;