'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The Panel component
 * @param  {String|Undefined} header   The header for the component
 * @param  {Object|Array}     children The child elements/components that appear
 *                                     inside the panel
 * @return {React.Element}             The React element describing this component
 */
// dependencies
//
var Panel = function Panel(_ref) {
    var style = _ref.style;
    var header = _ref.header;
    var children = _ref.children;

    var classes = (0, _classnames2.default)('panel', {
        'panel-danger': style === 'danger' || style === 'error',
        'panel-warning': style === 'warning' || style === 'warn',
        'panel-info': style === 'info',
        'panel-success': style === 'success' || style === 'ok',
        'panel-primary': style === 'primary',
        'panel-default': typeof style === 'undefined'
    });

    return _react2.default.createElement(
        'div',
        { className: classes },
        header ? _react2.default.createElement(
            'div',
            { className: 'panel-heading' },
            _react2.default.createElement(
                'h3',
                { className: 'panel-title' },
                header
            )
        ) : '',
        _react2.default.createElement(
            'div',
            { className: 'panel-body' },
            children
        )
    );
};

// set the property types for the Panel component
//
Panel.propTypes = {
    style: _react2.default.PropTypes.string,
    header: _react2.default.PropTypes.string,
    children: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.arrayOf(_react2.default.PropTypes.node), _react2.default.PropTypes.node])
};

// export the component
//
exports.default = Panel;