'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The Button component
 * @param  {Object} children  The children of this component
 * @param  {Boolean} disabled A flag to indicate whether the button should be
 *                            rendered as disabled
 * @param  {String} style     The style for the button
 * @param  {Function} onClick The onClick handler for the button
 * @return {React.Element}    The React element describing this component
 */
// dependencies
//
var Button = function Button(_ref) {
    var children = _ref.children;
    var disabled = _ref.disabled;
    var name = _ref.name;
    var style = _ref.style;
    var onClick = _ref.onClick;
    return _react2.default.createElement(
        'button',
        {
            className: (0, _classnames2.default)('btn', {
                'btn-danger': style === 'danger' || style === 'error',
                'btn-warning': style === 'warning' || style === 'warn',
                'btn-info': style === 'info',
                'btn-success': style === 'success' || style === 'ok',
                'btn-default': !style
            }),
            disabled: !!disabled,
            onClick: onClick,
            name: name
        },
        children || 'Submit'
    );
};

/**
 * The property types for the Button component
 * @type {Object}
 */
Button.propTypes = {
    disabled: _react2.default.PropTypes.bool,
    name: _react2.default.PropTypes.string,
    style: _react2.default.PropTypes.string,
    onClick: _react2.default.PropTypes.func,
    children: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.arrayOf(_react2.default.PropTypes.node), _react2.default.PropTypes.node])
};

// export the component
//
exports.default = Button;