'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _isArray = require('lodash/isArray');

var _isArray2 = _interopRequireDefault(_isArray);

var _flatMap = require('lodash/flatMap');

var _flatMap2 = _interopRequireDefault(_flatMap);

var _uniqueId = require('lodash/uniqueId');

var _uniqueId2 = _interopRequireDefault(_uniqueId);

var _classnames2 = require('classnames');

var _classnames3 = _interopRequireDefault(_classnames2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; } // dependencies
//


/**
 * The Dropdown component
 */
var Dropdown = function (_React$Component) {
    _inherits(Dropdown, _React$Component);

    /**
     * Construct the component instance
     * @param  {Object} props The component props
     */
    function Dropdown(props) {
        _classCallCheck(this, Dropdown);

        // generate a unique ID for this instance
        //
        var _this = _possibleConstructorReturn(this, (Dropdown.__proto__ || Object.getPrototypeOf(Dropdown)).call(this, props));

        _this.id = props.id || (0, _uniqueId2.default)('form-dropdown-');

        // do we have a value? if not, then we need call onChange (if it exists)
        // with the first option to ensure that the value is set
        //
        if (!props.value && props.onChange) {
            // is the list of options an array?
            //
            if ((0, _isArray2.default)(props.options)) {
                // yes - return the value of the first item (if we have one)
                //
                if (props.options.length > 0) {
                    props.onChange(props.options[0].value);
                }
            } else {
                // no - return the value of the first item in the first property
                // (if there is one)
                //
                var keys = Object.keys(props.options);

                if (keys.length > 0) {
                    props.onChange(props.options[keys[0]][0].value);
                }
            }
        }

        // bind `this` to the event handlers
        //
        _this.isValid = _this.isValid.bind(_this);
        _this.onChange = _this.onChange.bind(_this);
        return _this;
    }

    /**
     * Handle the `onChange` event for the select element
     * @param  {Object} event The event object
     */


    _createClass(Dropdown, [{
        key: 'onChange',
        value: function onChange(event) {
            // do we have an onChange handler? if so, call it with the appropriate
            // value
            //
            if (this.props.onChange) {
                // figure out which value to use
                //
                var value = this.isValid(event.target.value) ? event.target.value : '';

                if (this.props.options[0] && !value) {
                    value = this.props.options[0].value;
                }

                // call the onChange handler with the value
                //
                this.props.onChange(value);
            }
        }

        /**
         * Get the list of options as a flat array
         * @return {Array} The list of options
         */

    }, {
        key: 'getOptionsList',
        value: function getOptionsList() {
            // is it an array? if so, return it; otherwise, map it to a flat array
            //
            return (0, _isArray2.default)(this.props.options) ? this.props.options : (0, _flatMap2.default)(this.props.options, function (opt) {
                return opt;
            });
        }

        /**
         * Determine if a value is valid (ie. in the list of options)
         * @param  {String}  The value to check
         * @return {Boolean} True if the value is valid (ie. found in the array of
         *                   options); false otherwise
         */

    }, {
        key: 'isValid',
        value: function isValid() {
            var value = arguments.length <= 0 || arguments[0] === undefined ? this.props.value : arguments[0];

            return this.getOptionsList().findIndex(function (opt) {
                return '' + opt.value === '' + value;
            }) !== -1;
        }

        /**
         * Render the component
         * @return {React.Element} The React element describing the component
         */

    }, {
        key: 'render',
        value: function render() {
            var _this2 = this;

            // figure out what value to display
            //
            var value = this.isValid() ? this.props.value : '';
            if (this.props.options[0] && !value) {
                value = this.props.options[0].value;
            }

            // generate the label for the component
            //
            var label = this.props.label ? _react2.default.createElement(
                'label',
                {
                    htmlFor: this.id,
                    className: (0, _classnames3.default)('control-label', _defineProperty({}, 'col-xs-' + this.context.labelColumns, this.context.labelColumns))
                },
                this.props.label
            ) : null;

            // build the options
            //
            var options = null;

            // is the list of options an array or an object?
            //
            if ((0, _isArray2.default)(this.props.options)) {
                // it's an array - simply map it to a list of <option> elements
                //
                options = this.props.options.map(function (opt) {
                    return _react2.default.createElement(
                        'option',
                        { key: (0, _uniqueId2.default)('form-dropdown-option-'), value: opt.value },
                        opt.name
                    );
                });
            } else {
                // it's an object - build a list of options, separated into
                // optgroups by key
                //
                options = [];

                Object.keys(this.props.options).forEach(function (key) {
                    options.push(_react2.default.createElement(
                        'optgroup',
                        { key: (0, _uniqueId2.default)('form-dropdown-optgroup-'), label: key },
                        _this2.props.options[key].map(function (opt) {
                            return _react2.default.createElement(
                                'option',
                                { key: (0, _uniqueId2.default)('form-dropdown-option-'), value: opt.value },
                                opt.name
                            );
                        })
                    ));
                });
            }

            // generate the select element for the component
            //
            var select = _react2.default.createElement(
                'select',
                {
                    id: this.id,
                    name: this.props.name,
                    disabled: !!this.props.disabled,
                    className: 'form-control',
                    value: value,
                    onChange: this.onChange
                },
                options
            );

            // do we have columns for this component? if so, wrap the select element
            // in a div to implement those columns
            //
            if (this.context.labelColumns) {
                select = _react2.default.createElement(
                    'div',
                    {
                        className: (0, _classnames3.default)('form-dropdown-columns', 'col-xs-' + (12 - this.context.labelColumns))
                    },
                    select
                );
            }

            // return the component
            //
            return label ? _react2.default.createElement(
                'div',
                { className: 'form-group' },
                label,
                select
            ) : select;
        }
    }]);

    return Dropdown;
}(_react2.default.Component);

/**
 * The property types for the component
 * @type {Object}
 */


Dropdown.propTypes = {
    disabled: _react2.default.PropTypes.bool,
    id: _react2.default.PropTypes.string,
    label: _react2.default.PropTypes.string,
    name: _react2.default.PropTypes.string,
    value: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.string, _react2.default.PropTypes.number]),
    options: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.array, _react2.default.PropTypes.object]).isRequired,
    onChange: _react2.default.PropTypes.func
};

/**
 * The context types for the component
 * @type {Object}
 */
Dropdown.contextTypes = {
    labelColumns: _react2.default.PropTypes.number
};

// export the component
//
exports.default = Dropdown;