'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _uniqueId = require('lodash/uniqueId');

var _uniqueId2 = _interopRequireDefault(_uniqueId);

var _classnames2 = require('classnames');

var _classnames3 = _interopRequireDefault(_classnames2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; } // dependencies
//


/**
 * The RadioButtonGroup component
 */
var RadioButtonGroup = function (_React$Component) {
    _inherits(RadioButtonGroup, _React$Component);

    /**
     * Construct the component instance
     * @param  {Object} props The component props
     */
    function RadioButtonGroup(props) {
        _classCallCheck(this, RadioButtonGroup);

        // generate a unique ID for this element (used to tie the label to the
        // input elements)
        //
        var _this = _possibleConstructorReturn(this, (RadioButtonGroup.__proto__ || Object.getPrototypeOf(RadioButtonGroup)).call(this, props));

        _this.id = (0, _uniqueId2.default)('form-radiobuttongroup-');

        // build a list of permitted values from the options
        //
        _this.permittedValues = _this.props.options.map(function (opt) {
            return '' + opt.value;
        });

        // initialize the component state
        //
        _this.state = {
            value: _this.isPermittedValue(_this.props.value) ? '' + _this.props.value : '' + _this.props.options[0].value
        };

        // bind `this` to the onChange event handler
        //
        _this.onChange = _this.onChange.bind(_this);
        return _this;
    }

    /**
     * Handle a change to the input elements
     * @param  {Object} event The event object
     */


    _createClass(RadioButtonGroup, [{
        key: 'onChange',
        value: function onChange(event) {
            // get the current value & make sure it's a string
            //
            var value = '' + event.target.value;

            // has the value changed? if so, then update the state & call the
            // onChange handler
            //
            if (value !== this.state.value) {
                // update the component state
                //
                this.setState({ value: value });

                // do we have an onChange handler? if so, call it
                //
                if (this.props.onChange) {
                    this.props.onChange(value);
                }
            }
        }

        /**
         * Check a value to see if it's one of the permitted values
         * @param  {String}  value The value to check
         * @return {Boolean}       True if it's a permitted value; false otherwise
         */

    }, {
        key: 'isPermittedValue',
        value: function isPermittedValue(value) {
            return this.permittedValues.findIndex(function (val) {
                return val === '' + value;
            }) !== -1;
        }

        /**
         * Render the component
         * @return {React.Element} The React element describing the component
         */

    }, {
        key: 'render',
        value: function render() {
            var _this2 = this;

            // get the important values from the component properties
            //
            var _props = this.props;
            var label = _props.label;
            var options = _props.options;

            // render the label element for the component
            //

            var labelElement = label ? _react2.default.createElement(
                'label',
                {
                    htmlFor: this.id,
                    className: (0, _classnames3.default)('control-label', _defineProperty({}, 'col-xs-' + this.context.labelColumns, this.context.labelColumns))
                },
                label
            ) : null;

            // render the set of radio button elements for the component
            //
            var radios = options.map(function (opt) {
                return _react2.default.createElement(
                    'div',
                    { key: (0, _uniqueId2.default)('form-radiobuttongroup-option-'), className: 'radio' },
                    _react2.default.createElement(
                        'label',
                        null,
                        _react2.default.createElement('input', {
                            type: 'radio',
                            disabled: !!_this2.props.disabled,
                            name: _this2.id,
                            value: opt.value,
                            checked: _this2.state.value === opt.value,
                            onChange: _this2.onChange
                        }),
                        _react2.default.createElement(
                            'span',
                            null,
                            opt.name
                        )
                    )
                );
            });

            // do we have columns for this component? if so, wrap the radio buttons
            // in a div to implement the columns
            //
            if (this.context.labelColumns) {
                radios = _react2.default.createElement(
                    'div',
                    {
                        className: (0, _classnames3.default)('form-radiobuttongroup-input-columns', 'col-xs-' + (12 - this.context.labelColumns))
                    },
                    radios
                );
            }

            // render the whole component & return it
            //
            return _react2.default.createElement(
                'div',
                { className: 'form-group' },
                labelElement,
                radios
            );
        }
    }]);

    return RadioButtonGroup;
}(_react2.default.Component);

/**
 * The property types for the component
 * @type {Object}
 */


RadioButtonGroup.propTypes = {
    label: _react2.default.PropTypes.string,
    disabled: _react2.default.PropTypes.bool,
    options: _react2.default.PropTypes.array,
    value: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.string, _react2.default.PropTypes.number]),
    onChange: _react2.default.PropTypes.func
};

/**
 * The context types for the component
 * @type {Object}
 */
RadioButtonGroup.contextTypes = {
    labelColumns: _react2.default.PropTypes.number
};

// export the component
//
exports.default = RadioButtonGroup;