'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The SubmitButton component
 * @param  {String}   children   The label to display in the button
 * @param  {String}   name    The name for the component
 * @param  {String}   style   The style with which to display the button
 * @param  {Function} onClick The `onClick` handler for the button
 * @param  {Boolean}  isValid A flag (from the parent Form's context) indicating
 *                            whether the form to which this button is attached
 *                            is valid
 * @return {React.Element}    The React element describing this component
 */
// dependencies
//
var SubmitButton = function SubmitButton(_ref, _ref2) {
    var children = _ref.children;
    var name = _ref.name;
    var style = _ref.style;
    var onClick = _ref.onClick;
    var isValid = _ref2.isValid;
    return _react2.default.createElement(
        'button',
        {
            name: name,
            className: (0, _classnames2.default)('btn', {
                'btn-danger': style === 'danger' || style === 'error',
                'btn-warning': style === 'warning' || style === 'warn',
                'btn-info': style === 'info',
                'btn-success': style === 'success' || style === 'ok',
                'btn-default': !style
            }),
            disabled: !isValid,
            onClick: onClick
        },
        children || 'Submit'
    );
};

// define the property types for the component
//
SubmitButton.propTypes = {
    name: _react2.default.PropTypes.string,
    style: _react2.default.PropTypes.string,
    onClick: _react2.default.PropTypes.func,
    children: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.arrayOf(_react2.default.PropTypes.node), _react2.default.PropTypes.node])
};

// define the context types for values received from higher up the food chain
//
SubmitButton.contextTypes = {
    isValid: _react2.default.PropTypes.bool
};

// export the component
//
exports.default = SubmitButton;